@@ -157,9 +157,12 @@ MainWindow::MainWindow(QWidget *parent)
 void MainWindow::menuItemInvoked(QAction *action)
 {
     if (action->text() == "testPrinter") {
+// 下面注释的目的用于在 QDoc 生成文档是能够直接使用 \snippet 命令选取这段代码进行展示
+//! [0]
         DPrintPreviewDialog dialog(this);
         //测试保存PDF文件名称接口
         dialog.setDocName("test");
+        dialog.setPluginMimeData("secrecy");
 #ifdef AsynPreview
         dialog.setAsynPreview(31);
         connect(&dialog, QOverload<DPrinter *, const QVector<int> &>::of(&DPrintPreviewDialog::paintRequested),
@@ -184,7 +187,6 @@ void MainWindow::menuItemInvoked(QAction *action)
                         painter.resetTransform();
                         if (!firstPage)
                             _printer->newPage();
-                        // qApp->processEvents();
 
                         // 给出调用方widget界面作为打印内容
                         double xscale = _printer->pageRect().width() / double(this->width());
@@ -214,15 +216,16 @@ void MainWindow::menuItemInvoked(QAction *action)
                     }
                 });
         dialog.exec();
+//! [0]
         return;
     }
     if (action->text() == "dfm-settings") {
         QTemporaryFile tmpFile;
         tmpFile.open();
-        auto backend = new Dtk::Core::QSettingBackend(tmpFile.fileName(), this);
+        Dtk::Core::QSettingBackend backend(tmpFile.fileName());
 
         auto settings = Dtk::Core::DSettings::fromJsonFile(":/resources/data/dfm-settings.json");
-        settings->setBackend(backend);
+        settings->setBackend(&backend);
 
         DSettingsDialog dsd(this);
         dsd.updateSettings(settings);
@@ -233,10 +236,10 @@ void MainWindow::menuItemInvoked(QAction *action)
     if (action->text() == "dt-settings") {
         QTemporaryFile tmpFile;
         tmpFile.open();
-        auto backend = new Dtk::Core::QSettingBackend(tmpFile.fileName(), this);
+        Dtk::Core::QSettingBackend backend(tmpFile.fileName());
 
         auto settings = Dtk::Core::DSettings::fromJsonFile(":/resources/data/dt-settings.json");
-        settings->setBackend(backend);
+        settings->setBackend(&backend);
 
         QFontDatabase fontDatabase;
         auto fontFamliy = settings->option("base.font.family");
