@@ -109,18 +109,19 @@ public:
     ArrowHeaderLine *headerLine = nullptr;
 };
 
-/**
- * \~chinese \class DArrowLineDrawer
- * \~chinese \brief 一个美观的可展开的控件
- * \~chinese
- * \~chinese DArrowLineDrawer 继承自 DDrawer 并提供了了 ArrowHeaderLine (一个带有箭头标示的按钮)作为其固定的标题控件，也就是说跟 DDrawer 相比省去了提供标题控件的步骤，只需要提供内容控件即可，如果需要自定义标题控件应该使用 DDrawer 类。
- * \~chinese \sa  DDrawer
+/*!
+  \class Dtk::Widget::DArrowLineDrawer
+  \inmodule dtkwidget
+  \brief 一个美观的可展开的控件.
+  
+  DArrowLineDrawer 继承自 DDrawer 并提供了了 ArrowHeaderLine (一个带有箭头标示的按钮)作为其固定的标题控件，也就是说跟 DDrawer 相比省去了提供标题控件的步骤，只需要提供内容控件即可，如果需要自定义标题控件应该使用 DDrawer 类。
+  \sa  DDrawer
  */
 
-/**
- * \~chinese \brief 构造一个 DArrowLineDrawer 实例
- * \~chinese
- * \~chinese \param parent 为实例的父控件
+/*!
+  \brief 构造一个 DArrowLineDrawer 实例
+  
+  \a parent 为实例的父控件
  */
 DArrowLineDrawer::DArrowLineDrawer(QWidget *parent)
     : DDrawer(*new DArrowLineDrawerPrivate(this), parent)
@@ -135,10 +136,10 @@ DArrowLineDrawer::DArrowLineDrawer(QWidget *parent)
     setHeader(d->headerLine);
 }
 
-/**
- * \~chinese \brief 设置标题要显示的文字
- * \~chinese
- * \~chinese \param title 标题内容
+/*!
+  \brief 设置标题要显示的文字
+  
+  \a title 标题内容
  */
 void DArrowLineDrawer::setTitle(const QString &title)
 {
@@ -146,10 +147,10 @@ void DArrowLineDrawer::setTitle(const QString &title)
     d->headerLine->setTitle(title);
 }
 
-/**
- * \~chinese \brief 设置是否展开以显示内容控件
- * \~chinese
- * \~chinese \param value 为 true 即为显示，反之则反
+/*!
+  \brief 设置是否展开以显示内容控件
+  
+  \a value 为 true 即为显示，反之则反
  */
 void DArrowLineDrawer::setExpand(bool value)
 {
@@ -159,10 +160,10 @@ void DArrowLineDrawer::setExpand(bool value)
     DDrawer::setExpand(value);
 }
 
-/**
- * \~chinese \brief 获取标题控件
- * \~chinese \return 标题控件
- * \~chinese \sa ArrowHeaderLine DHeaderLine DBaseLine
+/*!
+  \brief 获取标题控件
+  \return 标题控件
+  \sa DHeaderLine DBaseLine
  */
 DBaseLine *DArrowLineDrawer::headerLine()
 {
