@@ -22,7 +22,7 @@
 #include "dstyle.h"
 
 #include <DGuiApplicationHelper>
-
+#include<qpa/qplatformnativeinterface.h>
 #ifdef Q_OS_LINUX
 #include <X11/extensions/shape.h>
 #include <QX11Info>
@@ -33,6 +33,10 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
+static bool isDwayland()
+{
+    return qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+}
 /*!
   \class Dtk::Widget::DArrowRectangle
   \inmodule dtkwidget
@@ -475,7 +479,7 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 
     d->m_backgroundColor = backgroundColor;
 
-    if (d->m_handle && d->m_backgroundColor.toRgb().alpha() < 255) {
+    if ((d->m_handle || isDwayland()) && d->m_backgroundColor.toRgb().alpha() < 255) {
         if (!d->m_blurBackground) {
             d->m_blurBackground = new DBlurEffectWidget(this);
             d->m_blurBackground->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
@@ -1112,6 +1116,9 @@ void DArrowRectanglePrivate::updateClipPath()
 {
     D_Q(DArrowRectangle);
 
+    if (!isDwayland() && !m_handle)
+        return;
+
     QPainterPath path;
 
     switch (m_arrowDirection) {
@@ -1133,7 +1140,7 @@ void DArrowRectanglePrivate::updateClipPath()
 
     if (m_handle) {
         m_handle->setClipPath(path);
-    } else {
+    } else if (DArrowRectangle::FloatWindow == floatMode && isDwayland()) {
         // clipPath without handle
         QPainterPathStroker stroker;
         stroker.setCapStyle(Qt::RoundCap);
@@ -1144,6 +1151,18 @@ void DArrowRectanglePrivate::updateClipPath()
 
         q->clearMask();
         q->setMask(polygon);
+        if (m_blurBackground)
+            m_blurBackground->setMaskPath(path);
+
+        if (QWidget *widget = q->window()) {
+            if (QWindow *w = widget->windowHandle()) {
+                QList<QPainterPath> painterPaths;
+                painterPaths << outPath.united(path);
+                // 背景模糊也要设置一个 path
+                qApp->platformNativeInterface()->setWindowProperty(w->handle(), "_d_windowBlurPaths",
+                                                                   QVariant::fromValue(painterPaths));
+            }
+        }
     }
 }
 
@@ -1208,8 +1227,17 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
             q->update();
             this->updateClipPath();
         }, Qt::QueuedConnection);
+    } else if (DArrowRectangle::FloatWidget == floatMode) {
+        DGraphicsGlowEffect *glowEffect = new DGraphicsGlowEffect;
+        glowEffect->setBlurRadius(q->shadowBlurRadius());
+        glowEffect->setDistance(m_shadowDistance);
+        glowEffect->setXOffset(q->shadowXOffset());
+        glowEffect->setYOffset(q->shadowYOffset());
+        q->setGraphicsEffect(glowEffect);
     } else {
-        m_wmHelper = nullptr;
+#ifndef QT_DEBUG
+        qDebug() << "wayland:" << isDwayland() << "floatMode:" << floatMode;
+#endif
     }
 }
 
