@@ -125,7 +125,7 @@ void DLineEdit::showAlertMessage(const QString &text, int duration)
 void DLineEdit::showAlertMessage(const QString &text, QWidget *follower, int duration)
 {
     D_D(DLineEdit);
-    d->control->showAlertMessage(text, follower ? follower : this, duration);
+    d->control->showAlertMessage(text, follower ? follower : this->lineEdit(), duration);
 }
 
 /*!
@@ -501,11 +501,42 @@ bool DLineEdit::eventFilter(QObject *watched, QEvent *event)
             return QWidget::eventFilter(watched, event);
         }
 
+        QLineEdit *pLineEdit = static_cast<QLineEdit*>(watched);
+        QMenu *menu = pLineEdit->createStandardContextMenu();
+
+        for (QAction *action : menu->actions()) {
+            if (action->text().startsWith(QLineEdit::tr("&Copy")) && !copyEnabled()  ) {
+                action->setEnabled(false);
+            }
+            if (action->text().startsWith(QLineEdit::tr("Cu&t")) && !cutEnabled()) {
+                action->setEnabled(false);
+            }
+        }
+        connect(menu, &QMenu::triggered, this, [pLineEdit](QAction *pAction) {
+            if (pAction->text().startsWith(QLineEdit::tr("Select All"))) {
+                QApplication::clipboard()->setText(pLineEdit->text(), QClipboard::Mode::Selection);
+            }
+        });
+
+        auto msg = QDBusMessage::createMethodCall("com.iflytek.aiassistant", "/",
+                                       "org.freedesktop.DBus.Peer", "Ping");
+        // 用之前 Ping 一下, 300ms 内没回复就认定是服务出问题，不再添加助手菜单项
+        // Fix：Bug-154857 此处不能使用 BlockWithGui 否则右键事件会被处理，事件传递到
+        //  DSearchEdit 上会导致 edit 获得焦点然后菜单弹出后又失去焦点，有闪烁现象。。
+        auto pingReply = QDBusConnection::sessionBus().call(msg, QDBus::Block, 300);
+        auto errorType = QDBusConnection::sessionBus().lastError().type();
+        if (errorType == QDBusError::Timeout || errorType == QDBusError::NoReply) {
+            qWarning() << pingReply << "\nwill not add aiassistant actions!";
+            menu->popup(static_cast<QContextMenuEvent*>(event)->globalPos());
+            event->accept();
+            return true;
+        }
+
         QDBusInterface testSpeech("com.iflytek.aiassistant",
                                    "/aiassistant/tts",
                                    "com.iflytek.aiassistant.tts",
                                    QDBusConnection::sessionBus());
-        //测试朗读接口是否开启
+        // 测试朗读接口是否开启
         QDBusReply<bool> speechReply = testSpeech.call(QDBus::AutoDetect, "getTTSEnable");
 
         QDBusInterface testReading("com.iflytek.aiassistant",
@@ -529,24 +560,6 @@ bool DLineEdit::eventFilter(QObject *watched, QEvent *event)
         //测试听写接口是否开启
         QDBusReply<bool> speechToTextReply = testSpeechToText.call(QDBus::AutoDetect, "getIatEnable");
 
-        QLineEdit *pLineEdit = static_cast<QLineEdit*>(watched);
-        QMenu *menu = pLineEdit->createStandardContextMenu();
-
-        for (QAction *action : menu->actions()) {
-            if (action->text().startsWith(QLineEdit::tr("&Copy")) && !copyEnabled()  ) {
-                action->setEnabled(false);
-            }
-            if (action->text().startsWith(QLineEdit::tr("Cu&t")) && !cutEnabled()) {
-                action->setEnabled(false);
-            }
-        }
-
-        connect(menu, &QMenu::triggered, this, [pLineEdit](QAction *pAction) {
-            if (pAction->text().startsWith(QLineEdit::tr("Select All"))) {
-                QApplication::clipboard()->setText(pLineEdit->text(), QClipboard::Mode::Selection);
-            }
-        });
-
         //朗读,翻译,听写都没有开启，则弹出默认菜单
         if (!speechReply.value() && !translateReply.value() && !speechToTextReply.value()) {
             menu->popup(static_cast<QContextMenuEvent*>(event)->globalPos());
