@@ -66,7 +66,7 @@ public:
     QList<Pop> pops;
 
     int     interval = 33;
-    int     value = 0;
+    int     value = -1;
 
     double  frontXOffset = 0;
     double  backXOffset = 0;
@@ -77,21 +77,16 @@ public:
 };
 
 /*!
-    \~chinese \class DWaterProgress
-    \~chinese \brief 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。
+    \class Dtk::Widget::DWaterProgress
+    \inmodule dtkwidget
 
-    \~chinese \image html dwaterprogress.png
+    \brief 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件.
+    \brief Use DWaterProgress to create an new water animation progress.
 
-    \~chinese 可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。并提供了可选的是否显示进度文字的选项。
-*/
+    \image html dwaterprogress.png
 
-/*!
-    \~english \class DWaterProgress
-    \~english \brief Use DWaterProgress to create an new water animation progress.
-
-    \~english \image html dwaterprogress.png
-
-    \~english Use DWaterProgress to create an new water animation progress. There is also an optional progress
+    可以使用 DWaterProgress 类快速创建圆形容器内水位高低指示进度的动画控件。并提供了可选的是否显示进度文字的选项。
+    Use DWaterProgress to create an new water animation progress. There is also an optional progress
     text can be set as visible via setTextVisible().
 */
 
@@ -115,8 +110,8 @@ DWaterProgress::~DWaterProgress()
 }
 
 /*!
- * \~english \brief get the current progress value
- * \~chinese \brief 当前进度值
+  \brief get the current progress value
+  \brief 当前进度值
  */
 int DWaterProgress::value() const
 {
@@ -125,8 +120,8 @@ int DWaterProgress::value() const
 }
 
 /*!
- * \~english \brief star water animation.
- * \~chinese \brief 开始水位动画
+  \brief star water animation.
+  \brief 开始水位动画
  */
 void DWaterProgress::start()
 {
@@ -135,8 +130,8 @@ void DWaterProgress::start()
 }
 
 /*!
- * \~english \brief stop water animation.
- * \~chinese \brief 停止水位动画
+  \brief stop water animation.
+  \brief 停止水位动画
  */
 void DWaterProgress::stop()
 {
@@ -145,8 +140,8 @@ void DWaterProgress::stop()
 }
 
 /*!
- * \~english \brief set the current progress value (range: 0~100)
- * \~chinese \brief 设置当前进度值，（范围 0~100）
+  \brief set the current progress \a value (range: 0~100)
+  \brief 设置当前进度值，（范围 0~100）
  */
 void DWaterProgress::setValue(int value)
 {
@@ -159,11 +154,11 @@ void DWaterProgress::setValue(int value)
 }
 
 /*!
- * \~english \brief set progress text visible or not
- * \~chinese \brief 设置是否显示进度
- *
- * \~english set the progress text value(like 50% when value is 50) visible.
- * \~chinese 设置进度文字是否显示，如值为 50 时显示 50% 。
+  \brief set progress text \a visible or not
+  \brief 设置是否显示进度
+
+  set the progress text value(like 50% when value is 50) \a visible.
+  设置进度文字是否显示，如值为 50 时显示 50% 。
  */
 void DWaterProgress::setTextVisible(bool visible)
 {
@@ -219,8 +214,6 @@ void DWaterProgressPrivate::initUI()
     D_Q(DWaterProgress);
     q->setMinimumSize(100, 100);
 
-    value = 0;
-
     timer = new QTimer(q);
     timer->setInterval(interval);
     resizePixmap(q->size());
